@@ -1,6 +1,6 @@
 # This package contains generic base classes for APIClients
 
-from .APIClientBase import APIClientBase
+from .APIClientBase import APIClientBase, APIClientException
 from .LoginSession import LoginSession, NullLoginSession
 from ._version import get_versions
 __version__ = get_versions()['version']
